@@ -15,7 +15,7 @@ public:
 private:
 	wxDBusConnection* m_pConnection;
 
-	DECLARE_EVENT_TABLE();
+	DECLARE_EVENT_TABLE()
 	void OnSignal(wxDBusConnectionEvent& event);
 	void OnAsyncReply(wxDBusConnectionEvent& event);
 
