@@ -30,7 +30,7 @@ std::list<CControlSocket::t_lockInfo> CControlSocket::m_lockInfoList;
 BEGIN_EVENT_TABLE(CControlSocket, wxEvtHandler)
 	EVT_TIMER(wxID_ANY, CControlSocket::OnTimer)
 	EVT_COMMAND(wxID_ANY, fzOBTAINLOCK, CControlSocket::OnObtainLock)
-END_EVENT_TABLE();
+END_EVENT_TABLE()
 
 COpData::COpData(enum Command op_Id)
 	: opId(op_Id)
@@ -405,7 +405,10 @@ bool CControlSocket::ParsePwdReply(wxString reply, bool unquoted /*=false*/, con
 				reply = _T("");
 		}
 		else
+		{
 			reply = reply.Mid(pos1 + 1, pos2 - pos1 - 1);
+			reply.Replace(_T("\"\""), _T("\""));
+		}
 	}
 
 	m_CurrentPath.SetType(m_pCurrentServer->GetType());
@@ -1441,3 +1444,45 @@ void CControlSocket::CreateLocalDir(const wxString &local_file)
 	n->dir = last_successful;
 	m_pEngine->AddNotification(n);
 }
+
+int CControlSocket::List(CServerPath, wxString, int)
+{
+	return FZ_REPLY_NOTSUPPORTED;
+}
+
+int CControlSocket::FileTransfer(const wxString, const CServerPath &,
+					const wxString &, bool,
+					const CFileTransferCommand::t_transferSettings&)
+{
+	return FZ_REPLY_NOTSUPPORTED;
+}
+
+int CControlSocket::RawCommand(const wxString&)
+{
+	return FZ_REPLY_NOTSUPPORTED;
+}
+
+int CControlSocket::Delete(const CServerPath&, const std::list<wxString>&)
+{
+	return FZ_REPLY_NOTSUPPORTED;
+}
+
+int CControlSocket::RemoveDir(const CServerPath&, const wxString&)
+{
+	return FZ_REPLY_NOTSUPPORTED;
+}
+
+int CControlSocket::Mkdir(const CServerPath&)
+{
+	return FZ_REPLY_NOTSUPPORTED;
+}
+
+int CControlSocket::Rename(const CRenameCommand&)
+{
+	return FZ_REPLY_NOTSUPPORTED;
+}
+
+int CControlSocket::Chmod(const CChmodCommand&)
+{
+	return FZ_REPLY_NOTSUPPORTED;
+}
\ No newline at end of file
