@@ -4,7 +4,7 @@
 /* This class is responsible for parsing the directory listings returned by
  * the server.
  * Unfortunatly, RFC959 did not specify the format of directory listings, so
- * each server uses its own format. In addition to that, in most cases the 
+ * each server uses its own format. In addition to that, in most cases the
  * listings were not designed to be machine-parsable, they were meant to be
  * human readable by users of that particular server.
  * By far the most common format is the one returned by the Unix "ls -l"
@@ -17,8 +17,8 @@
  * Some servers send multiline listings where a single entry can span two
  * lines, this has to be detected as well, as far as possible.
  *
- * Some servers send MVS style listings which can consist of just the 
- * filename without any additional data. In order to prevent problems, this 
+ * Some servers send MVS style listings which can consist of just the
+ * filename without any additional data. In order to prevent problems, this
  * format is only parsed if the server is in fact recognizes as MVS server.
  *
  * Please see tests/dirparsertest.cpp for a list of supported formats and the
@@ -35,10 +35,22 @@
 class CLine;
 class CToken;
 class CControlSocket;
+
+namespace listingEncoding
+{
+	enum type
+	{
+		unknown,
+		normal,
+		ebcdic
+	};
+}
+
+
 class CDirectoryListingParser
 {
 public:
-	CDirectoryListingParser(CControlSocket* pControlSocket, const CServer& server);
+	CDirectoryListingParser(CControlSocket* pControlSocket, const CServer& server, listingEncoding::type encoding = listingEncoding::unknown);
 	~CDirectoryListingParser();
 
 	CDirectoryListing Parse(const CServerPath &path);
@@ -73,7 +85,7 @@ protected:
 	bool ParseAsIBM_MVS_Tape(CLine *pLine, CDirentry &entry);
 	int ParseAsMlsd(CLine *pLine, CDirentry &entry);
 	bool ParseAsOS9(CLine *pLine, CDirentry &entry);
-	
+
 	// Only call this if servertype set to ZVM since it conflicts
 	// with other formats.
 	bool ParseAsZVM(CLine *pLine, CDirentry &entry);
@@ -92,10 +104,13 @@ protected:
 
 	bool GetMonthFromName(const wxString& name, int &month);
 
+	void DeduceEncoding();
+	void ConvertEncoding(char *pData, int len);
+
 	CControlSocket* m_pControlSocket;
 
 	static std::map<wxString, int> m_MonthNamesMap;
-	
+
 	struct t_list
 	{
 		char *p;
@@ -105,6 +120,7 @@ protected:
 
 	std::list<t_list> m_DataList;
 	std::list<CDirentry> m_entryList;
+	wxLongLong m_totalData;
 
 	CLine *m_prevLine;
 
@@ -112,10 +128,12 @@ protected:
 
 	bool m_fileListOnly;
 	std::list<wxString> m_fileList;
-	
+
 	bool m_maybeMultilineVms;
 
 	wxTimeSpan m_timezoneOffset;
+
+	listingEncoding::type m_listingEncoding;
 };
 
 #endif
