@@ -28,7 +28,7 @@ CRateLimiter* CRateLimiter::Create(COptionsBase* pOptions)
 		m_pTheRateLimiter = new CRateLimiter(pOptions);
 	else
 		++m_pTheRateLimiter->m_usageCount;
-	
+
 	return m_pTheRateLimiter;
 }
 
@@ -139,12 +139,11 @@ void CRateLimiter::RemoveObject(CRateLimiterObject* pObject)
 
 void CRateLimiter::OnTimer(wxTimerEvent& event)
 {
-	std::list<CRateLimiterObject*> objectsToUnwait;
 	for (int i = 0; i < 2; ++i)
 	{
 		m_tokenDebt[i] = 0;
 
-		if (!m_objectList.size())
+		if (m_objectList.empty())
 			continue;
 
 		wxLongLong limit = GetLimit((enum rate_direction)i);
@@ -164,7 +163,7 @@ void CRateLimiter::OnTimer(wxTimerEvent& event)
 
 		// Get amount of tokens for each object
 		wxLongLong tokensPerObject = tokens / m_objectList.size();
-		
+
 		if (tokensPerObject == 0)
 			tokensPerObject = 1;
 		tokens = 0;
@@ -237,7 +236,7 @@ void CRateLimiter::WakeupWaitingObjects()
 			m_wakeupList[i].pop_front();
 			if (!pObject->m_waiting[i])
 				continue;
-			
+
 			wxASSERT(pObject->m_bytesAvailable != 0);
 			pObject->m_waiting[i] = false;
 
