@@ -37,6 +37,8 @@ public:
 
 	enum TlsState GetState() const { return m_tlsState; }
 
+	wxString GetProtocolName();
+	wxString GetKeyExchange();
 	wxString GetCipherName();
 	wxString GetMacName();
 
@@ -86,6 +88,8 @@ protected:
 	void OnRead();
 	void OnSend();
 
+	bool ExtractCert(const void* in, CCertificate& out);
+
 	bool m_canReadFromSocket;
 	bool m_canWriteToSocket;
 	bool m_canCheckCloseSocket;
