@@ -18,18 +18,26 @@ int GetRandomNumber(int low, int high);
 
 // Under some locales (e.g. Turkish), there is a different
 // relationship between the letters a-z and A-Z.
-// In Turkish for example there are different types of i 
+// In Turkish for example there are different types of i
 // (dotted and dotless), with i lowercase dotted and I
 // uppercase dotless.
 // If needed, use this function to transform the case manually
 // and locale-independently
 void MakeLowerAscii(wxString& str);
 
-enum _dependency
-{
-	dependency_gnutls
+// Strongly typed enum would be nice, but we need to support older compilers still.
+namespace dependency {
+enum type {
+	wxwidgets,
+	gnutls,
+	sqlite,
+	count
 };
+}
 
-wxString GetDependencyVersion(enum _dependency dependency);
+wxString GetDependencyName( dependency::type d );
+wxString GetDependencyVersion( dependency::type d );
+
+wxString ListTlsCiphers(const wxString& priority);
 
 #endif //__MISC_H__
