@@ -51,7 +51,7 @@ protected:
 	// Select a list of items based in their names.
 	// Sort order may not change between call to RememberSelectedItems and
 	// ReselectItems
-	void ReselectItems(const std::list<wxString>& selectedNames, wxString focused);
+	void ReselectItems(const std::list<wxString>& selectedNames, wxString focused, bool ensureVisible = false);
 
 #ifdef __WXMSW__
 	void DisplayDrives();
@@ -88,7 +88,7 @@ protected:
 	int m_dropTarget;
 
 	// Event handlers
-	DECLARE_EVENT_TABLE();
+	DECLARE_EVENT_TABLE()
 	void OnItemActivated(wxListEvent& event);
 	void OnContextMenu(wxContextMenuEvent& event);
 	void OnMenuUpload(wxCommandEvent& event);
