@@ -231,6 +231,7 @@ CLocalTreeView::CLocalTreeView(wxWindow* parent, wxWindowID id, CState *pState,
 	CStateEventHandler(pState),
 	m_pQueueView(pQueueView)
 {
+	wxGetApp().AddStartupProfileRecord(_T("CLocalTreeView::CLocalTreeView"));
 #ifdef __WXMAC__
 	SetFont(wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT));
 #endif
@@ -386,6 +387,7 @@ wxTreeItemId CLocalTreeView::GetSubdir(wxTreeItemId parent, const wxString& subD
 
 bool CLocalTreeView::DisplayDrives(wxTreeItemId parent)
 {
+	wxGetApp().AddStartupProfileRecord(_T("CLocalTreeView::DisplayDrives"));
 	long drivesToHide = 0;
 	// Adhere to the NODRIVES group policy
 	wxRegKey key(_T("HKEY_CURRENT_USER\\Software\\Microsoft\\Windows\\CurrentVersion\\Policies\\Explorer"));
@@ -438,6 +440,7 @@ bool CLocalTreeView::DisplayDrives(wxTreeItemId parent)
 		if (drive.Right(1) == _T("\\"))
 			drive = drive.RemoveLast();
 
+		wxGetApp().AddStartupProfileRecord(wxString::Format(_T("CLocalTreeView::DisplayDrives adding drive %s"), drive.c_str()));
 		wxTreeItemId item = AppendItem(parent, drive, GetIconIndex(dir, pDrive));
 		AppendItem(item, _T(""));
 		SortChildren(parent);
@@ -445,6 +448,8 @@ bool CLocalTreeView::DisplayDrives(wxTreeItemId parent)
 		pDrive += wxStrlen(pDrive) + 1;
 	}
 
+	wxGetApp().AddStartupProfileRecord(_T("CLocalTreeView::DisplayDrives adding drives done"));
+
 	delete [] drives;
 
 	return true;
@@ -1608,9 +1613,5 @@ void CLocalTreeView::OnMenuOpen(wxCommandEvent& event)
 	if (path == _T(""))
 		return;
 
-	wxString url = CState::GetAsURL(path);
-	if (url == _T(""))
-		return;
-
-	wxLaunchDefaultBrowser(url);
+	CState::OpenInFileManager(path);
 }
