@@ -73,6 +73,7 @@ BEGIN_EVENT_TABLE(CMainFrame, wxFrame)
 	EVT_SIZE(CMainFrame::OnSize)
 	EVT_MENU(wxID_ANY, CMainFrame::OnMenuHandler)
 	EVT_FZ_NOTIFICATION(wxID_ANY, CMainFrame::OnEngineEvent)
+	EVT_COMMAND(wxID_ANY, fzEVT_UPDATE_LED_TOOLTIP, CMainFrame::OnUpdateLedTooltip)
 	EVT_TOOL(XRCID("ID_TOOLBAR_DISCONNECT"), CMainFrame::OnDisconnect)
 	EVT_MENU(XRCID("ID_MENU_SERVER_DISCONNECT"), CMainFrame::OnDisconnect)
 	EVT_TOOL(XRCID("ID_TOOLBAR_CANCEL"), CMainFrame::OnCancel)
@@ -208,6 +209,7 @@ protected:
 CMainFrame::CMainFrame()
 	: m_comparisonToggleAcceleratorId(wxNewId())
 {
+	wxGetApp().AddStartupProfileRecord(_T("CMainFrame::CMainFrame"));
 	wxRect screen_size = CWindowStateManager::GetScreenDimensions();
 
 	wxSize initial_size;
@@ -335,8 +337,6 @@ CMainFrame::CMainFrame()
 
 	m_pContextControl->CreateTab();
 
-	m_pContextControl->GetCurrentControls();
-
 	switch (message_log_position)
 	{
 	case 1:
@@ -502,6 +502,7 @@ void CMainFrame::OnSize(wxSizeEvent &event)
 
 bool CMainFrame::CreateMenus()
 {
+	wxGetApp().AddStartupProfileRecord(_T("CMainFrame::CreateMenus"));
 	if (m_pMenuBar)
 	{
 		SetMenuBar(0);
@@ -523,6 +524,7 @@ bool CMainFrame::CreateMenus()
 
 bool CMainFrame::CreateQuickconnectBar()
 {
+	wxGetApp().AddStartupProfileRecord(_T("CMainFrame::CreateQuickconnectBar"));
 	delete m_pQuickconnectBar;
 
 	m_pQuickconnectBar = new CQuickconnectBar();
@@ -736,7 +738,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 	else if (event.GetId() == XRCID("ID_MENU_HELP_GETTINGHELP") ||
 			 event.GetId() == XRCID("ID_MENU_HELP_BUGREPORT"))
 	{
-		wxString url(_T("http://filezilla-project.org/support.php?type=client&mode="));
+		wxString url(_T("https://filezilla-project.org/support.php?type=client&mode="));
 		if (event.GetId() == XRCID("ID_MENU_HELP_GETTINGHELP"))
 			url += _T("help");
 		else
@@ -1008,7 +1010,7 @@ void CMainFrame::OnEngineEvent(wxEvent &event)
 			{
 				CAsyncRequestNotification* pAsyncRequest = reinterpret_cast<CAsyncRequestNotification *>(pNotification);
 				if (pAsyncRequest->GetRequestID() == reqId_fileexists)
-					m_pQueueView->ProcessNotification(pNotification);
+					m_pQueueView->ProcessNotification(pEngine, pNotification);
 				else
 				{
 					if (pAsyncRequest->GetRequestID() == reqId_certificate)
@@ -1025,7 +1027,7 @@ void CMainFrame::OnEngineEvent(wxEvent &event)
 			}
 			break;
 		case nId_transferstatus:
-			m_pQueueView->ProcessNotification(pNotification);
+			m_pQueueView->ProcessNotification(pEngine, pNotification);
 			break;
 		case nId_sftp_encryption:
 			{
@@ -1050,8 +1052,32 @@ void CMainFrame::OnEngineEvent(wxEvent &event)
 	}
 }
 
+void CMainFrame::OnUpdateLedTooltip(wxCommandEvent& event)
+{
+	wxString tooltipText;
+
+	wxFileOffset downloadSpeed = m_pQueueView->GetCurrentDownloadSpeed();
+	wxFileOffset uploadSpeed = m_pQueueView->GetCurrentUploadSpeed();
+
+	CSizeFormat::_format format = static_cast<CSizeFormat::_format>(COptions::Get()->GetOptionVal(OPTION_SIZE_FORMAT));
+	if (format == CSizeFormat::bytes)
+		format = CSizeFormat::iec;
+
+	const wxString downloadSpeedStr = CSizeFormat::Format(downloadSpeed, true, format,
+														  COptions::Get()->GetOptionVal(OPTION_SIZE_USETHOUSANDSEP) != 0,
+														  COptions::Get()->GetOptionVal(OPTION_SIZE_DECIMALPLACES));
+	const wxString uploadSpeedStr = CSizeFormat::Format(uploadSpeed, true, format,
+														COptions::Get()->GetOptionVal(OPTION_SIZE_USETHOUSANDSEP) != 0,
+														COptions::Get()->GetOptionVal(OPTION_SIZE_DECIMALPLACES));
+	tooltipText.Printf(_("Download speed: %s/s\nUpload speed: %s/s"), downloadSpeedStr.c_str(), uploadSpeedStr.c_str());
+
+	m_pActivityLed[0]->SetToolTip(tooltipText);
+	m_pActivityLed[1]->SetToolTip(tooltipText);
+}
+
 bool CMainFrame::CreateToolBar()
 {
+	wxGetApp().AddStartupProfileRecord(_T("CMainFrame::CreateToolBar"));
 	if (m_pToolBar)
 	{
 #ifdef __WXMAC__
@@ -2477,6 +2503,25 @@ void CMainFrame::ProcessCommandLine()
 	if (!pCommandLine)
 		return;
 
+	wxString local;
+	if ((local = pCommandLine->GetOption(CCommandLine::local)) != _T(""))
+	{
+		
+		if (!wxDir::Exists(local))
+		{
+			wxString str = _("Path not found:");
+			str += _T("\n") + local;
+			wxMessageBox(str, _("Syntax error in command line"));
+			return;
+		}
+		
+		CState *pState = CContextManager::Get()->GetCurrentContext();
+		if (!pState)
+			return;
+			
+		pState->SetLocalDir(local);
+	}	
+	
 	wxString site;
 	if (pCommandLine->HasSwitch(CCommandLine::sitemanager))
 	{
@@ -2583,7 +2628,7 @@ WXLRESULT CMainFrame::MSWWindowProc(WXUINT nMsg, WXWPARAM wParam, WXLPARAM lPara
 		// get the new display layout from Windows.
 		//
 		// Note: Both the factory pattern as well as the dynamic object system
-		//       are perfect example of bad design.
+		//	   are perfect example of bad design.
 		//
 		wxModule* pDisplayModule = (wxModule*)wxCreateDynamicObject(_T("wxDisplayModule"));
 		if (pDisplayModule)
