@@ -2,7 +2,7 @@
 #define __STATUSVIEW_H__
 
 class CFastTextCtrl;
-class CStatusView :	public wxWindow
+class CStatusView : public wxWindow
 {
 public:
 	CStatusView(wxWindow* parent, wxWindowID id);
@@ -25,7 +25,7 @@ protected:
 
 	void OnSize(wxSizeEvent &event);
 
-	DECLARE_EVENT_TABLE();
+	DECLARE_EVENT_TABLE()
 	void OnContextMenu(wxContextMenuEvent& event);
 	void OnClear(wxCommandEvent& event);
 	void OnCopy(wxCommandEvent& event);
