@@ -8,12 +8,12 @@
 #include "local_filesys.h"
 
 // Defined in optionspage_edit.cpp
-bool UnquoteCommand(wxString& command, wxString& arguments);
+bool UnquoteCommand(wxString& command, wxString& arguments, bool is_dde = false);
 bool ProgramExists(const wxString& editor);
 
 class CChangedFileDialog : public wxDialogEx
 {
-	DECLARE_EVENT_TABLE();
+	DECLARE_EVENT_TABLE()
 	void OnYes(wxCommandEvent& event);
 	void OnNo(wxCommandEvent& event);
 };
@@ -204,9 +204,9 @@ void CEditHandler::Release()
 		if (m_lockfile_descriptor >= 0)
 			close(m_lockfile_descriptor);
 #endif
-		
+
 		wxRemoveFile(m_localDir + _T("empty_file_yq744zm"));
-		
+
 		RemoveAll(true);
 		wxRmdir(m_localDir);
 	}
@@ -813,7 +813,7 @@ bool CEditHandler::UploadFile(enum fileType type, std::list<t_fileData>::iterato
 		return false;
 	}
 
-	m_pQueue->QueueFile(false, false, file, iter->name, localPath, iter->remotePath, iter->server, wxLongLong(size.GetHi(), size.GetLo()), type);
+	m_pQueue->QueueFile(false, false, file, iter->name, localPath, iter->remotePath, iter->server, wxLongLong(size.GetHi(), size.GetLo()), type, priority_high);
 	m_pQueue->QueueFile_Finish(true);
 
 	return true;
@@ -985,6 +985,8 @@ wxString CEditHandler::GetSystemOpenCommand(wxString file, bool &program_exists)
 		program_exists = false;
 
 		wxString editor;
+		bool is_dde = false;
+#ifdef __WXMSW__
 		if (cmd.Left(7) == _T("WX_DDE#"))
 		{
 			// See wxWidget's wxExecute in src/msw/utilsexc.cpp
@@ -994,12 +996,16 @@ wxString CEditHandler::GetSystemOpenCommand(wxString file, bool &program_exists)
 			if (pos < 1)
 				return cmd;
 			editor = editor.Left(pos);
+			is_dde = true;
 		}
 		else
+#endif
+		{
 			editor = cmd;
+		}
 
 		wxString args;
-		if (!UnquoteCommand(editor, args) || editor.empty())
+		if (!UnquoteCommand(editor, args, is_dde) || editor.empty())
 			return cmd;
 
 		if (!PathExpand(editor))
