@@ -35,9 +35,16 @@ public:
 	};
 
 	virtual bool operator()(int a, int b) const = 0;
-	virtual ~CListViewSort() { } // Without this empty destructor GCC complains
+	virtual ~CListViewSort() {} // Without this empty destructor GCC complains
 };
 
+namespace genericTypes {
+	enum type {
+		file,
+		directory
+	};
+}
+
 template<class CFileData> class CFileListCtrl : public wxListCtrlEx, public CComparableListing
 {
 public:
@@ -148,6 +155,8 @@ private:
 	CSharedPointer<CGtkEventCallbackProxyBase> m_gtkEventCallbackProxy;
 #endif
 
+	wxString m_genericTypes[2];
+
 	DECLARE_EVENT_TABLE()
 	void OnColumnClicked(wxListEvent &event);
 	void OnColumnRightClicked(wxListEvent& event);
