@@ -29,8 +29,8 @@ public:
 	bool HasFileName() const { return m_fileName.IsOk(); }
 
 	// Sets error description on failure
-	TiXmlElement* Load(const wxString& name, bool create = true);
-	TiXmlElement* Load(const wxFileName& fileName = wxFileName(), bool create = true);
+	TiXmlElement* Load(const wxString& name);
+	TiXmlElement* Load(const wxFileName& fileName = wxFileName());
 
 	wxString GetError() const { return m_error; }
 	int GetRawDataLength();
@@ -97,7 +97,7 @@ bool GetTextElementBool(TiXmlElement* node, const char* name, bool defValue = fa
 
 // Opens the specified XML file if it exists or creates a new one otherwise.
 // Returns 0 on error.
-TiXmlElement* GetXmlFile(wxFileName file, bool create = true, wxString *error = 0);
+TiXmlElement* GetXmlFile(wxFileName file, wxString *error = 0);
 
 // Save the XML document to the given file
 bool SaveXmlFile(const wxFileName& file, TiXmlNode* node, wxString* error = 0, bool move = false);
