@@ -45,6 +45,21 @@ union sockaddr_u
     struct sockaddr_in sin;
 };
 
+/* 
+ * Access to sockaddr types without breaking C strict aliasing rules.
+ */
+union sockaddr_union {
+#ifdef NO_IPV6
+    struct sockaddr_in storage;
+#else
+    struct sockaddr_storage storage;
+    struct sockaddr_in6 sin6;
+#endif
+    struct sockaddr sa;
+    struct sockaddr_in sin;
+    struct sockaddr_un su;
+};
+
 /*
  * We used to typedef struct Socket_tag *Socket.
  *
@@ -317,7 +332,9 @@ static int sk_nextaddr(SockAddr addr, SockAddrStep *step)
 
 void sk_getaddr(SockAddr addr, char *buf, int buflen)
 {
-
+    /* XXX not clear what we should return for Unix-domain sockets; let's
+     * hope the question never arises */
+    assert(addr->superfamily != UNIX);
     if (addr->superfamily == UNRESOLVED) {
 	strncpy(buf, addr->hostname, buflen);
 	buf[buflen-1] = '\0';
@@ -342,7 +359,9 @@ void sk_getaddr(SockAddr addr, char *buf, int buflen)
 
 int sk_hostname_is_local(char *name)
 {
-    return !strcmp(name, "localhost");
+    return !strcmp(name, "localhost") ||
+	   !strcmp(name, "::1") ||
+	   !strncmp(name, "127.", 4);
 }
 
 #define ipv4_is_loopback(addr) \
@@ -350,19 +369,13 @@ int sk_hostname_is_local(char *name)
 
 static int sockaddr_is_loopback(struct sockaddr *sa)
 {
-    struct sockaddr_in *sin;
-#ifndef NO_IPV6
-    struct sockaddr_in6 *sin6;
-#endif
-
-    switch (sa->sa_family) {
+    union sockaddr_union *u = (union sockaddr_union *)sa;
+    switch (u->sa.sa_family) {
       case AF_INET:
-	sin = (struct sockaddr_in *)sa;
-	return ipv4_is_loopback(sin->sin_addr);
+	return ipv4_is_loopback(u->sin.sin_addr);
 #ifndef NO_IPV6
       case AF_INET6:
-	sin6 = (struct sockaddr_in6 *)sa;
-	return IN6_IS_ADDR_LOOPBACK(&sin6->sin6_addr);
+	return IN6_IS_ADDR_LOOPBACK(&u->sin6.sin6_addr);
 #endif
       case AF_UNIX:
 	return TRUE;
@@ -373,9 +386,10 @@ static int sockaddr_is_loopback(struct sockaddr *sa)
 
 int sk_address_is_local(SockAddr addr)
 {
-
     if (addr->superfamily == UNRESOLVED)
 	return 0;                      /* we don't know; assume not */
+    else if (addr->superfamily == UNIX)
+	return 1;
     else {
 #ifndef NO_IPV6
 	return sockaddr_is_loopback(addr->ais->ai_addr);
@@ -529,12 +543,8 @@ Socket sk_register(OSSocket sockfd, Plug plug)
 static int try_connect(Actual_Socket sock)
 {
     int s;
-#ifndef NO_IPV6
-    struct sockaddr_in6 a6;
-#endif
-    struct sockaddr_in a;
-    struct sockaddr_un au;
-    const struct sockaddr *sa;
+    union sockaddr_union u;
+    const union sockaddr_union *sa;
     int err = 0;
     short localport;
     int fl, salen, family;
@@ -602,10 +612,7 @@ static int try_connect(Actual_Socket sock)
 	localport = 0;		       /* just use port 0 (ie kernel picks) */
 
     /* BSD IP stacks need sockaddr_in zeroed before filling in */
-    memset(&a,'\0',sizeof(struct sockaddr_in));
-#ifndef NO_IPV6
-    memset(&a6,'\0',sizeof(struct sockaddr_in6));
-#endif
+    memset(&u,'\0',sizeof(u));
 
     /* We don't try to bind to a local address for UNIX domain sockets.  (Why
      * do we bother doing the bind when localport == 0 anyway?) */
@@ -617,18 +624,18 @@ static int try_connect(Actual_Socket sock)
 #ifndef NO_IPV6
 	    if (family == AF_INET6) {
 		/* XXX use getaddrinfo to get a local address? */
-		a6.sin6_family = AF_INET6;
-		a6.sin6_addr = in6addr_any;
-		a6.sin6_port = htons(localport);
-		retcode = bind(s, (struct sockaddr *) &a6, sizeof(a6));
+		u.sin6.sin6_family = AF_INET6;
+		u.sin6.sin6_addr = in6addr_any;
+		u.sin6.sin6_port = htons(localport);
+		retcode = bind(s, &u.sa, sizeof(u.sin6));
 	    } else
 #endif
 	    {
 		assert(family == AF_INET);
-		a.sin_family = AF_INET;
-		a.sin_addr.s_addr = htonl(INADDR_ANY);
-		a.sin_port = htons(localport);
-		retcode = bind(s, (struct sockaddr *) &a, sizeof(a));
+		u.sin.sin_family = AF_INET;
+		u.sin.sin_addr.s_addr = htonl(INADDR_ANY);
+		u.sin.sin_port = htons(localport);
+		retcode = bind(s, &u.sa, sizeof(u.sin));
 	    }
 	    if (retcode >= 0) {
 		err = 0;
@@ -659,32 +666,31 @@ static int try_connect(Actual_Socket sock)
 	/* XXX would be better to have got getaddrinfo() to fill in the port. */
 	((struct sockaddr_in *)sock->step.ai->ai_addr)->sin_port =
 	    htons(sock->port);
-	sa = (const struct sockaddr *)sock->step.ai->ai_addr;
+	sa = (const union sockaddr_union *)sock->step.ai->ai_addr;
 	salen = sock->step.ai->ai_addrlen;
 	break;
       case AF_INET6:
 	((struct sockaddr_in *)sock->step.ai->ai_addr)->sin_port =
 	    htons(sock->port);
-	sa = (const struct sockaddr *)sock->step.ai->ai_addr;
+	sa = (const union sockaddr_union *)sock->step.ai->ai_addr;
 	salen = sock->step.ai->ai_addrlen;
 	break;
 #else
       case AF_INET:
-	a.sin_family = AF_INET;
-	a.sin_addr.s_addr = htonl(sock->addr->addresses[sock->step.curraddr]);
-	a.sin_port = htons((short) sock->port);
-	sa = (const struct sockaddr *)&a;
-	salen = sizeof a;
+	u.sin.sin_family = AF_INET;
+	u.sin.sin_addr.s_addr = htonl(sock->addr->addresses[sock->step.curraddr]);
+	u.sin.sin_port = htons((short) sock->port);
+	sa = &u;
+	salen = sizeof u.sin;
 	break;
 #endif
       case AF_UNIX:
 	assert(sock->port == 0);       /* to catch confused people */
-	assert(strlen(sock->addr->hostname) < sizeof au.sun_path);
-	memset(&au, 0, sizeof au);
-	au.sun_family = AF_UNIX;
-	strcpy(au.sun_path, sock->addr->hostname);
-	sa = (const struct sockaddr *)&au;
-	salen = sizeof au;
+	assert(strlen(sock->addr->hostname) < sizeof u.su.sun_path);
+	u.su.sun_family = AF_UNIX;
+	strcpy(u.su.sun_path, sock->addr->hostname);
+	sa = &u;
+	salen = sizeof u.su;
 	break;
 
       default:
@@ -696,7 +702,7 @@ static int try_connect(Actual_Socket sock)
     if (fl != -1)
 	fcntl(s, F_SETFL, fl | O_NONBLOCK);
 
-    if ((connect(s, sa, salen)) < 0) {
+    if ((connect(s, &(sa->sa), salen)) < 0) {
 	if ( errno != EINPROGRESS ) {
 	    err = errno;
 	    goto ret;
@@ -776,11 +782,10 @@ Socket sk_newlistener(char *srcaddr, int port, Plug plug, int local_host_only, i
 #ifndef NO_IPV6
     struct addrinfo hints, *ai;
     char portstr[6];
-    struct sockaddr_in6 a6;
 #endif
-    struct sockaddr *addr;
+    union sockaddr_union u;
+    union sockaddr_union *addr;
     int addrlen;
-    struct sockaddr_in a;
     Actual_Socket ret;
     int retcode;
     int address_family;
@@ -867,52 +872,51 @@ Socket sk_newlistener(char *srcaddr, int port, Plug plug, int local_host_only, i
         sprintf(portstr, "%d", port);
         retcode = getaddrinfo(srcaddr, portstr, &hints, &ai);
 	if (retcode == 0) {
-	    addr = ai->ai_addr;
+	    addr = (union sockaddr_union *)ai->ai_addr;
 	    addrlen = ai->ai_addrlen;
 	}
 #else
-        memset(&a,'\0',sizeof(struct sockaddr_in));
-        a.sin_family = AF_INET;
-        a.sin_port = htons(port);
-        a.sin_addr.s_addr = inet_addr(srcaddr);
-        if (a.sin_addr.s_addr != (in_addr_t)(-1)) {
+        memset(&u,'\0',sizeof u);
+        u.sin.sin_family = AF_INET;
+        u.sin.sin_port = htons(port);
+        u.sin.sin_addr.s_addr = inet_addr(srcaddr);
+        if (u.sin.sin_addr.s_addr != (in_addr_t)(-1)) {
             /* Override localhost_only with specified listen addr. */
-            ret->localhost_only = ipv4_is_loopback(a.sin_addr);
+            ret->localhost_only = ipv4_is_loopback(u.sin.sin_addr);
         }
-        addr = (struct sockaddr *)&a;
-        addrlen = sizeof(a);
+        addr = &u;
+        addrlen = sizeof(u.sin);
         retcode = 0;
 #endif
     }
 
     if (retcode != 0) {
+        memset(&u,'\0',sizeof u);
 #ifndef NO_IPV6
         if (address_family == AF_INET6) {
-            memset(&a6,'\0',sizeof(struct sockaddr_in6));
-            a6.sin6_family = AF_INET6;
-            a6.sin6_port = htons(port);
+            u.sin6.sin6_family = AF_INET6;
+            u.sin6.sin6_port = htons(port);
             if (local_host_only)
-                a6.sin6_addr = in6addr_loopback;
+                u.sin6.sin6_addr = in6addr_loopback;
             else
-                a6.sin6_addr = in6addr_any;
-            addr = (struct sockaddr *)&a6;
-            addrlen = sizeof(a6);
+                u.sin6.sin6_addr = in6addr_any;
+            addr = &u;
+            addrlen = sizeof(u.sin6);
         } else
 #endif
         {
-            memset(&a,'\0',sizeof(struct sockaddr_in));
-            a.sin_family = AF_INET;
-            a.sin_port = htons(port);
+            u.sin.sin_family = AF_INET;
+            u.sin.sin_port = htons(port);
 	    if (local_host_only)
-		a.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
+		u.sin.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
 	    else
-		a.sin_addr.s_addr = htonl(INADDR_ANY);
-            addr = (struct sockaddr *)&a;
-            addrlen = sizeof(a);
+		u.sin.sin_addr.s_addr = htonl(INADDR_ANY);
+            addr = &u;
+            addrlen = sizeof(u.sin);
         }
     }
 
-    retcode = bind(s, addr, addrlen);
+    retcode = bind(s, &addr->sa, addrlen);
     if (retcode < 0) {
         close(s);
 	ret->error = strerror(errno);
@@ -977,8 +981,7 @@ static void sk_tcp_close(Socket sock)
 void *sk_getxdmdata(void *sock, int *lenp)
 {
     Actual_Socket s = (Actual_Socket) sock;
-
-    union sockaddr_u addr;
+    union sockaddr_union u;
     socklen_t addrlen;
     char *buf;
     static unsigned int unix_addr = 0xFFFFFFFF;
@@ -989,23 +992,23 @@ void *sk_getxdmdata(void *sock, int *lenp)
     if (s->fn != &tcp_fn_table)
 	return NULL;		       /* failure */
 
-    addrlen = sizeof(addr);
-    if (getsockname(s->s, &addr.sa, &addrlen) < 0)
+    addrlen = sizeof(u);
+    if (getsockname(s->s, &u.sa, &addrlen) < 0)
 	return NULL;
-    switch(addr.sa.sa_family) {
+    switch(u.sa.sa_family) {
       case AF_INET:
 	*lenp = 6;
 	buf = snewn(*lenp, char);
-	PUT_32BIT_MSB_FIRST(buf, ntohl(addr.sin.sin_addr.s_addr));
-	PUT_16BIT_MSB_FIRST(buf+4, ntohs(addr.sin.sin_port));
+	PUT_32BIT_MSB_FIRST(buf, ntohl(u.sin.sin_addr.s_addr));
+	PUT_16BIT_MSB_FIRST(buf+4, ntohs(u.sin.sin_port));
 	break;
 #ifndef NO_IPV6
     case AF_INET6:
 	*lenp = 6;
 	buf = snewn(*lenp, char);
-	if (IN6_IS_ADDR_V4MAPPED(&addr.sin6.sin6_addr)) {
-	    memcpy(buf, addr.sin6.sin6_addr.s6_addr + 12, 4);
-	    PUT_16BIT_MSB_FIRST(buf+4, ntohs(addr.sin6.sin6_port));
+	if (IN6_IS_ADDR_V4MAPPED(&u.sin6.sin6_addr)) {
+	    memcpy(buf, u.sin6.sin6_addr.s6_addr + 12, 4);
+	    PUT_16BIT_MSB_FIRST(buf+4, ntohs(u.sin6.sin6_port));
 	} else
 	    /* This is stupid, but it's what XLib does. */
 	    memset(buf, 0, 6);
@@ -1205,13 +1208,13 @@ static int net_select_result(int fd, int event)
 	     * On a listening socket, the readability event means a
 	     * connection is ready to be accepted.
 	     */
-	    union sockaddr_u ss;
-	    socklen_t addrlen = sizeof(ss);
+	    union sockaddr_union su;
+	    socklen_t addrlen = sizeof(su);
 	    int t;  /* socket of connection */
             int fl;
 
-	    memset(&ss, 0, addrlen);
-	    t = accept(s->s, &ss.sa, &addrlen);
+	    memset(&su, 0, addrlen);
+	    t = accept(s->s, &su.sa, &addrlen);
 	    if (t < 0) {
 		break;
 	    }
@@ -1221,7 +1224,7 @@ static int net_select_result(int fd, int event)
                 fcntl(t, F_SETFL, fl | O_NONBLOCK);
 
 	    if (s->localhost_only &&
-		!sockaddr_is_loopback(&ss.sa)) {
+		!sockaddr_is_loopback(&su.sa)) {
 		close(t);	       /* someone let nonlocal through?! */
 	    } else if (plug_accepting(s->plug, t)) {
 		close(t);	       /* denied or error */
@@ -1427,6 +1430,23 @@ int net_service_lookup(char *service)
 	return 0;
 }
 
+char *get_hostname(void)
+{
+    int len = 128;
+    char *hostname = NULL;
+    do {
+	len *= 2;
+	hostname = sresize(hostname, len, char);
+	if ((gethostname(hostname, len) < 0) &&
+	    (errno != ENAMETOOLONG)) {
+	    sfree(hostname);
+	    hostname = NULL;
+	    break;
+	}
+    } while (strlen(hostname) >= len-1);
+    return hostname;
+}
+
 SockAddr platform_get_x11_unix_address(const char *sockpath, int displaynum)
 {
     SockAddr ret = snew(struct SockAddr_tag);
